# Rich-SMI

[![PyPI version](https://badge.fury.io/py/richsmi.svg)](https://badge.fury.io/py/richsmi)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/richsmi)
[![Deploy to PyPI](https://github.com/urasakikeisuke/richsmi/actions/workflows/deploy_pypi.yml/badge.svg?branch=main)](https://github.com/urasakikeisuke/richsmi/actions/workflows/deploy_pypi.yml)
[![Pylint](https://github.com/urasakikeisuke/richsmi/actions/workflows/pylint.yml/badge.svg?branch=main)](https://github.com/urasakikeisuke/richsmi/actions/workflows/pylint.yml)

A terminal based graphical GPU monitoring tool inspired by NVIDIA System Management Interface (a.k.a. nvidia-smi) and htop.

## Installing
```bash
pip3 install richsmi
```

## Usage
Just run the following command on your terminal:

```bash
richsmi --loop 0.5 # where 0.5 is the time interval, in seconds.
```
